@@ -99,15 +99,14 @@ EMULSION (Epidemiological Multi-Level Simulation framework)
 Contributors and contact:
 -------------------------
 
-    - Sébastien Picault (sebastien.picault@inra.fr)
+    - Sébastien Picault (sebastien.picault@inrae.fr)
     - Yu-Lin Huang
     - Vianney Sicard
     - Sandie Arnoux
     - Gaël Beaunée
-    - Pauline Ezanno (pauline.ezanno@inra.fr)
+    - Pauline Ezanno (pauline.ezanno@inrae.fr)
 
-    BIOEPAR, INRAE, Oniris, Atlanpole La Chantrerie,
-    Nantes CS 44307 CEDEX, France
+    INRAE, Oniris, BIOEPAR, 44300, Nantes, France
 
 
 How to cite:
@@ -186,7 +185,7 @@ from   emulsion.tools.misc          import load_class
 from   emulsion.tools.plot          import plot_outputs
 from   emulsion.tools.simulation    import MultiSimulation
 
-VERSION = '1.1.0'
+VERSION = '1.1.1'
 DEFAULT_VERSION = "1.0"
 LICENSE = 'Apache-2.0'
 DEFAULT_LICENSE = "Apache-2.0"
