@@ -12,15 +12,14 @@ All functions in this module can be used in EMULSION models.
 # Contributors and contact:
 # -------------------------
 # 
-#     - Sébastien Picault (sebastien.picault@inra.fr)
+#     - Sébastien Picault (sebastien.picault@inrae.fr)
 #     - Yu-Lin Huang
 #     - Vianney Sicard
 #     - Sandie Arnoux
 #     - Gaël Beaunée
-#     - Pauline Ezanno (pauline.ezanno@inra.fr)
+#     - Pauline Ezanno (pauline.ezanno@inrae.fr)
 # 
-#     BIOEPAR, INRAE, Oniris, Atlanpole La Chantrerie,
-#     Nantes CS 44307 CEDEX, France
+#     INRAE, Oniris, BIOEPAR, 44300, Nantes, France
 # 
 # 
 # How to cite:
@@ -192,6 +191,41 @@ def MAX(*values):
 #                       | |     __/ |
 #                       |_|    |___/
 
+def MIN(*values):
+    """Return a the minimum of all values.
+
+    Parameters
+    ----------
+    *values: list
+        boolean values separated by commas
+
+    Returns
+    -------
+    float:
+        the lowest value
+    """
+    return min(values)
+
+MIN.__USER_FUNCTION__ = ['Functions Available for Models']
+
+def MAX(*values):
+    """Return a the maximum of all values.
+
+    Parameters
+    ----------
+    *values: list
+        boolean values separated by commas
+
+    Returns
+    -------
+    float:
+        the highest value
+    """
+    return max(values)
+
+MAX.__USER_FUNCTION__ = ['Functions Available for Models']
+
+
 
 def random_bool(proba_success: float) -> int:
     """Return a random boolean value (actually, 0 or 1) depending on
